@@ -356,13 +356,6 @@ $buildinfo_checksums->add_from_file($dsc_fname,
     key => $srcpkg->get_basename(1) . ".dsc");
 print " successful!\n";
 
-my $dscverifyexe = 'dscverify';
-if ($PROGRAM_NAME eq "scripts/debrebuild.pl" && -x "scripts/dscverify.pl") {
-    $dscverifyexe = "scripts/dscverify.pl";
-}
-
-0 == system $dscverifyexe, ($dsc_fname) or die "$dscverifyexe failed\n";
-
 my $environment = $cdata->{"Environment"};
 if (not defined($environment)) {
     die "need Environment field\n";
