@@ -415,6 +415,17 @@ if ($opt{list}) {
                 LWP::Simple::mirror($file_url, "$opt{destdir}/$file_name");
             }
         }
+
+        if ($dsc_name) {
+            my $dscverifyexe = 'dscverify';
+            if ($progname eq "scripts/debsnap.pl" && -x "scripts/dscverify.pl")
+            {
+                $dscverifyexe = "scripts/dscverify.pl";
+            }
+
+            0 == system $dscverifyexe, ("$opt{destdir}/$dsc_name")
+              or die "$dscverifyexe failed\n";
+        }
     }
 }
 
